summaryrefslogtreecommitdiff
path: root/indra/viewer_components/login
diff options
context:
space:
mode:
authorRider Linden <rider@lindenlab.com>2015-09-18 11:54:38 -0700
committerRider Linden <rider@lindenlab.com>2015-09-18 11:54:38 -0700
commita8ab084678aa36b38e1df74c8addf666a2774d3b (patch)
treee16f7076b9e0ca0d265b96221756894cebb22121 /indra/viewer_components/login
parent75c6549fde060e974c90636685962ee373f94202 (diff)
Tweek to naming postEventAndSuspend -> postAndSuspend
Diffstat (limited to 'indra/viewer_components/login')
-rwxr-xr-xindra/viewer_components/login/lllogin.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/indra/viewer_components/login/lllogin.cpp b/indra/viewer_components/login/lllogin.cpp
index 1feb41faf6..ad3d84b8e5 100755
--- a/indra/viewer_components/login/lllogin.cpp
+++ b/indra/viewer_components/login/lllogin.cpp
@@ -175,7 +175,7 @@ void LLLogin::Impl::login_(std::string uri, LLSD login_params)
request["op"] = "rewriteURI";
request["uri"] = uri;
request["reply"] = replyPump.getName();
- rewrittenURIs = llcoro::postEventAndSuspend(request, srv_pump_name, filter);
+ rewrittenURIs = llcoro::postAndSuspend(request, srv_pump_name, filter);
// EXP-772: If rewrittenURIs fail, try original URI as a fallback.
rewrittenURIs.append(uri);
} // we no longer need the filter
@@ -215,13 +215,13 @@ void LLLogin::Impl::login_(std::string uri, LLSD login_params)
sendProgressEvent("offline", "authenticating", progress_data);
// We expect zero or more "Downloading" status events, followed by
// exactly one event with some other status. Use postEventAndSuspend() the
// first time, because -- at least in unit-test land -- it's
// possible for the reply to arrive before the post() call
// returns. Subsequent responses, of course, must be awaited
// without posting again.
for (mAuthResponse = validateResponse(loginReplyPump.getName(),
- llcoro::postEventAndSuspend(request, xmlrpcPump, loginReplyPump, "reply"));
+ llcoro::postAndSuspend(request, xmlrpcPump, loginReplyPump, "reply"));
mAuthResponse["status"].asString() == "Downloading";
mAuthResponse = validateResponse(loginReplyPump.getName(),
llcoro::suspendUntilEventOn(loginReplyPump)))
@@ -215,13 +215,13 @@ void LLLogin::Impl::login_(std::string uri, LLSD login_params)
sendProgressEvent("offline", "authenticating", progress_data);
// We expect zero or more "Downloading" status events, followed by
- // exactly one event with some other status. Use postEventAndSuspend() the
+ // exactly one event with some other status. Use postAndSuspend() the
// first time, because -- at least in unit-test land -- it's
// possible for the reply to arrive before the post() call